package com.zswl.cloud.springBatch.client.model.dfy.Hotel.response;

import com.zswl.cloud.springBatch.client.model.dfy.DfyResponseBase;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Date;
import java.util.List;

@Data
@NoArgsConstructor
@AllArgsConstructor
public class RatePlanInfoResponse extends DfyResponseBase {

    private Datas data;


    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    class Datas {

        private List<RoomInfo> roomInfo;

    }

    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    class RoomInfo {
        // 物理房型ID
        private Long roomId;

        // 房型中文名
        private String roomNameCn;

        // 房型面积大小
        private String area;

        // 是否可加床
        private String isExtraBed;

        // 床型描述
        private String bedDescription;

        // 图片列表
        private List<Pic> pictures;

        // 无烟房
        private String noSmoking;

        // 房型所在楼层数
        private String floor;

        // 价格计划列表信息
        private List<RatePlanInfo> ratePlanInfo;

        // 设施数组
        private List<Facility> facilities;

        // 窗型
        private Integer window; // 0=无窗, 1=部分有窗, 2=有窗, 3=不确定, 4=内窗, 5=天窗, 6=封闭窗, 7=飘窗

        // 宽带
        private Integer broadband; // 1=免费提供, 2=不提供此服务, 3=收费提供, 4=部分收费, 5=部分提供并收费, 6=部分能提供并免费, 7=部分提供并只有部分和收费, 8=有, 9=不确定

        // WiFi
        private Integer wifi; // 1=免费提供, 2=不提供此服务, 3=收费提供, 4=部分收费, 5=部分提供并收费, 6=部分能提供并免费, 7=部分提供并只有部分和收费, 8=有, 9=不确定

    }

    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    class Pic {
        private String picName;

        private String path;
    }

    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    class RatePlanInfo {

        // 价格计划ID
        private String id;

        // 价格计划名称
        private String name;

        // 床型简称
        private String bedType;

        // 床型描述
        private String bedInfo;

        // 早餐（文本描述）
        private String mealInfo;

        // 早餐（结构化）
        private Meal meal;

        // 网络描述
        private String networkInfo;

        // wifi服务
        private String wifi;

        // 宾客类型：0或1 (所有宾客)、2 (内宾)、3 (中宾)、4 (外宾)
        private Integer guestType;

        // 发票开具方式
        private Integer invoiceType;

        // 每间房最多可住人数
        private Integer maxOccupancy;

        // 是否立即确认
        private Boolean instantConfirm;

        // 取消政策（文本描述）
        private CancelInfo cancel;

        // 取消政策（结构化）
        private Refund refund;

        // 促销信息
        private List<PromotionRule> promotionRules;

        // 每日价格，以“|”分隔，数量需与入住/离店时间对应
        private String guidedPrice;

        // 库存量（提供参考），房间每天的库存量，与销售指导价对应；以“|”分隔
        private String counts;

        // 平均结算价 averagePrice=ratePrice+taxAndFeePrice(（选中天数+间数的总结算价）/天数/间数)
        private Integer averagePrice;

        // 平均房费价(（选中天数+间数的总房费）/天数/间数)
        private Integer ratePrice;

        // 平均税费价，国内酒店通常为0(（选中天数+间数的总税费）/天数/间数)
        private Integer taxAndFeePrice;

        // 默认值为0; 为1时...
        private Integer otaForbid;

    }

    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    class Facility {

        private String code;
        private String name;
        private List<SubFacilities> tmpSubFacilities;
    }

    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    class SubFacilities {

        private String subCode;
        private String subName;
    }

    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    class CancelInfo {

        // 取消描述
        private String name;

        // 取消政策类型(1不可取销,2限时取消,3收费取消)
        private Integer type;

        // 取消政策描述
        private String desc;
    }

    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    class Meal {
        // 早餐
        private MealDetail breakfast;
    }

    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    class MealDetail {

        // 早餐情况，>=0，以“|”分隔，2|1表示第一天2人早餐，第二天1人早餐
        private String count;

        // 餐食的详细描述，可为空。且当count="99"时，以desc描述为准
        private String desc;
    }

    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    class Refund {

        // Other fields...

        // true代表预订的房间可按如下规则取消
        private Boolean returnable;

        // 详情的取消规则，包含多个refundRule次级子节点
        private List<RefundRule> refundRules;

        // 不可取消周期通常用于节日或旺季，此规则优先级较普通取消规则高，在这个日期范围内不能取消。
        private NonRefundableRange nonRefundableRange;

        // 取消规则中时间点的时区信息，不填写则默认为北京时间。
        private String timeZone;
    }

    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    class RefundRule {

        // 离入住当天24:00之前的小时数，如：checkin=2015-01-23, before = 6 代表 2015-01-23 18:00:00
        private String before;

        // 规则类型，NO_DEDUCTION（不扣减）、DEDUCT_BY_AMOUNT（扣减金额）、DEDUCT_BY_PERCENT（百分比扣减）、
        //DEDUCT_FIRST_NIGHT（扣除首晚）
        private String type;

        // 取消所需要扣减的数值
        private String value;
    }

    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    class NonRefundableRange {

        // 不可取消周期起始日期
        private Date fromDate;

        // 不可取消周期结束日期
        private Date toDate;

    }

    @Data
    @NoArgsConstructor
    @AllArgsConstructor
    class PromotionRule {

        // 销类型
        //FREE_GIFT.礼包
        //仅当code=FREE_GIFT时需要关注，其他类型不需要处理
        private String code;

        // 促销描述
        private String desc;

    }


}
