package com.zswl.cloud.springBatch.client.model.dfy.Ticket.request;


import com.zhongshu.payment.client.type.Channel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

import javax.validation.constraints.NotNull;
import java.util.List;

@Data
@AllArgsConstructor
@NoArgsConstructor
public class CreateOrderNewRequest {

    @ApiModelProperty(required = true)
    @NotNull
    private String epId;

    @ApiModelProperty(required = true)
    @NotNull
    private Channel channel;
    // 分销商订单号，非空时，可防止重复下单。若重复下单，则返回之前已生成的orderId，且isNewFlag=0。
    @ApiModelProperty(hidden = true)
    private String sourceOrderId;

    // 笛风账号
    @ApiModelProperty(hidden = true)
    private String acctId;

    // 门票产品ID
    @ApiModelProperty(required = true)
    @NotNull
    private int productId;

    @ApiModelProperty(required = true)
    @NotNull
    private String scenicId;

    // 出游日期. “YYYY-MM-DD”。请在前台限制，只有价格日历中存在的团期，才能作为出游日期。
    private String startTime;

    // 预订数量
    private Integer bookNumber;

    // 取票人信息
    private ContactInfo contact;

    // 游客资料列表。“门票详情接口->custInfoLimit“=2、3、6、7时，此字段必填。
    private List<VisitorInfo> touristList;

    private DeliveryInfo delivery;

    //使用笛风券金额
    //
    //使用笛风券会自动扣减订单金额，比如预订产品总额100元，使用旅游券10元，则下单后订单金额为90元；
    //
    //假如使用笛风券金额=预订产品总额，则订单金额为0元，并且下单后不需要调用【出票（代扣）接口】，会自动出票，因为这种情况系统认为钱已经付清了；
    //
    //如遇退票、预订失败等情况，已使用的笛风券会自动退回；
    private Integer couponValue;


    @Data
    @AllArgsConstructor
    @NoArgsConstructor
    public static class ContactInfo {
        // 取票人姓名
        private String contactName;

        // 取票人邮箱。当“门票详情接口->admissionVoucherCode”=205或302时必传，否则不要传。
        private String contactEmail;

        // 取票人手机号码（入园凭证会发送到此手机号码上，请务必保证手机号码真实有效）
        private String contactTel;

        // 证件类型。当“门票详情接口->custInfoLimit”=4、6、7时必传；否则不要传。选项参照“门票详情接口->certificateType”字段。
        private Integer psptType;

        // 证件号码。当“门票详情接口->custInfoLimit”=4、6、7时必传；否则不要传。
        private String psptId;

    }

    @Data
    @AllArgsConstructor
    @NoArgsConstructor
    public static class VisitorInfo {
        // 游客姓名
        private String name;

        // 证件类型
        private Integer psptType;

        // 证件号码
        private String psptId;

        // 电话号码
        private String tel;

        // 邮箱
        private String email;


    }

    @Data
    @AllArgsConstructor
    @NoArgsConstructor
    public static class DeliveryInfo {
        // 配送类型
        private Integer deliveryType;

        // 收件人
        private String receiverName;

        // 收件电话
        private String telNum;

        // 收件地址
        private String deliveryEndAddress;

        // 邮编
        private String zipCode;


    }


}
