package com.zswl.cloud.springBtach.server.core.api.dfy;

import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONUtil;
import com.zswl.cloud.springBatch.client.model.dfy.DfyBaseData;
import com.zswl.cloud.springBatch.client.model.dfy.DfyRequestBase;
import com.zswl.cloud.springBatch.client.model.dfy.Hotel.request.*;
import com.zswl.cloud.springBatch.client.model.dfy.Hotel.response.*;
import com.zswl.cloud.springBtach.server.core.dao.ApiLogDao;
import com.zswl.cloud.springBtach.server.core.domain.ApiLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

@Component
public class DomesticHotelApi {

    @Autowired
    ApiLogDao apiLogDao;

    @Value("${dfy.host}")
    private String host;

    @Value("${dfy.jd.acctId}")
    private String acctId;

    @Value("${dfy.jd.secretkey}")
    private String secretKey;


    @Value("${dfy.jd.apikey}")
    private String apiKey;

    // 目的地搜索

    public QueryNewResponse queryNew(QueryNewRequest queryNewRequest) {

        String post = post(queryNewRequest, "/DomesticHotel/hotel/destination/queryNew");
        return JSONUtil.toBean(post, QueryNewResponse.class);

    }

    public HotelListResponse hotelList(HotelListRequest hotelListRequest) {

        String post = post(hotelListRequest, "/DomesticHotel/query/hotelList");
        return JSONUtil.toBean(post, HotelListResponse.class);

    }

    public HotelDetailResponse hotelDetail(HotelDetailRequest hotelDetailRequest) {

        String post = post(hotelDetailRequest, "/DomesticHotel/query/hotelDetail");
        return JSONUtil.toBean(post, HotelDetailResponse.class);

    }

    public RatePlanInfoResponse ratePlanInfo(RatePlanInfoRequest ratePlanInfoRequest) {

        String post = post(ratePlanInfoRequest, "/DomesticHotel/query/ratePlanInfo");
        return JSONUtil.toBean(post, RatePlanInfoResponse.class);

    }

    public RatePlanResponse ratePlan(RatePlanRequest ratePlanRequest) {

        String post = post(ratePlanRequest, "/DomesticHotel/realTime/ratePlan");
        return JSONUtil.toBean(post, RatePlanResponse.class);

    }

    public AddOrderResponse addOrder(AddOrderRequest addOrderRequest) {

        addOrderRequest.setAcctId(acctId);
        String post = post(addOrderRequest, "/DomesticHotel/query/addOrder");
        return JSONUtil.toBean(post, AddOrderResponse.class);

    }

    public OrderDetailResponse orderDetail(OrderDetailRequest orderDetailRequest) {
        orderDetailRequest.setAcctId(acctId);
        String post = post(orderDetailRequest, "/DomesticHotel/query/orderDetail");
        return JSONUtil.toBean(post, OrderDetailResponse.class);

    }


    public SubmitOrderResponse submitOrder(SubmitOrderRequest submitOrderRequest) {

        submitOrderRequest.setAcctId(acctId);
        String post = post(submitOrderRequest, "/DomesticHotel/submitOrder");
        return JSONUtil.toBean(post, SubmitOrderResponse.class);

    }

    public CancelOrderResponse cancelOrder(CancelOrderRequest cancelOrderRequest) {

        cancelOrderRequest.setAcctId(acctId);
        String post = post(cancelOrderRequest, "/DomesticHotel/query/cancelOrder");
        return JSONUtil.toBean(post, CancelOrderResponse.class);

    }

    private String post(DfyBaseData dfyBaseData, String url) {

        DfyRequestBase dfyRequestBase = new DfyRequestBase(dfyBaseData);
        dfyRequestBase.setApiKey(apiKey);
        String signature = Signature.getSignature(JSONUtil.parseObj(dfyRequestBase), secretKey);
        dfyRequestBase.setSign(signature);

        String post = HttpUtil.post(host + url, JSONUtil.toJsonStr(dfyRequestBase));
        ApiLog apiLog = new ApiLog();
        apiLog.setSystem("Hotel");
        apiLog.setService(url);
        apiLog.setRequest(JSONUtil.toJsonStr(dfyRequestBase));
        apiLog.setResponse(JSONUtil.toJsonStr(post));
        apiLogDao.save(apiLog);
        return post;

    }


}
