package com.zswl.cloud.springBtach.server.core.api.dfy;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONUtil;
import com.zswl.cloud.springBatch.client.model.dfy.DfyBaseData;
import com.zswl.cloud.springBatch.client.model.dfy.DfyRequestBase;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.request.*;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.response.*;
import com.zswl.cloud.springBtach.server.core.dao.ApiLogDao;
import com.zswl.cloud.springBtach.server.core.domain.ApiLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

@Component
public class TicketApi {

    @Autowired
    ApiLogDao apiLogDao;

    @Value("${dfy.host}")
    private String host;

    @Value("${dfy.mp.acctId}")
    private String acctId;

    @Value("${dfy.mp.secretkey}")
    private String secretKey;


    @Value("${dfy.mp.apikey}")
    private String apiKey;

    public TicketApi(ApiLogDao apiLogDao) {
        this.apiLogDao = apiLogDao;
    }

    // 景点列表查询

    public ScenicListResponse scenicList(ScenicListRequest scenicRequest) {

        String post = post(scenicRequest, "/Ticket/scenicList");

        return JSONUtil.toBean(post, ScenicListResponse.class);

    }


    // 景点详情接口

    public ScenicDetailResponse scenicDetail(ScenicDetailRequest scenicDetailRequest) {

        String post = post(scenicDetailRequest, "/Ticket/scenicDetail");
        return JSONUtil.toBean(post, ScenicDetailResponse.class);
    }

    // 特权门票查询接口
    public PrivilegeTicketListResponse privilegeTicketList(PrivilegeTicketListRequest privilegeTicketListRequest) {

        String post = post(privilegeTicketListRequest, "/Ticket/privilegeTicketList");
        return JSONUtil.toBean(post, PrivilegeTicketListResponse.class);
    }


    // 门票详情接口
    public DetailResponse detail(DetailRequest detailRequest) {

        String post = post(detailRequest, "/Ticket/detail");
        return JSONUtil.toBean(post, DetailResponse.class);
    }


    // 创建订单接口
    public CreateOrderNewResponse createOrderNew(CreateOrderNewRequest2 createOrderNewRequest) {

        createOrderNewRequest.setAcctId(acctId);
        String post = post(createOrderNewRequest, "/Ticket/createOrderNew");
        return JSONUtil.toBean(post, CreateOrderNewResponse.class);
    }


    // 取消订单
    public void cancelOrder(CancelOrderRequest cancelOrderRequest) {
        post(cancelOrderRequest, "/Ticket/cancelOrder");
    }


    // 出票(代扣)接口
    public SubmitOrderResponse submitOrderResponse(SubmitOrderRequest submitOrderRequest) {
        submitOrderRequest.setAcctId(acctId);
        String post = post(submitOrderRequest, "/Ticket/submitOrder");
        return JSONUtil.toBean(post, SubmitOrderResponse.class);
    }

    // 订单详情接口
    public OrderDetailResponse orderDetail(OrderDetailRequest orderDetailRequest) {
        orderDetailRequest.setAcctId(acctId);
        String post = post(orderDetailRequest, "/Ticket/orderDetail");
        return JSONUtil.toBean(post, OrderDetailResponse.class);
    }

    // 订单状态接口
    public OrderStatusResponse orderStatus(OrderStatusRequest orderStatusRequest) {
        String post = post(orderStatusRequest, "/Ticket/orderStatus");
        return JSONUtil.toBean(post, OrderStatusResponse.class);
    }

    // 核销查询接口
    public VerifyOrderResponse verifyOrder(VerifyOrderRequest verifyOrderRequest) {
        String post = post(verifyOrderRequest, "/Ticket/verifyOrder");
        return JSONUtil.toBean(post, VerifyOrderResponse.class);
    }

    // 退票申请接口
    public TuiPiaoResponse tuiPiao(TuiPiaoRequest tuiPiaoRequest) {
        String post = post(tuiPiaoRequest, "/Ticket/tuiPiao");
        return JSONUtil.toBean(post, TuiPiaoResponse.class);
    }

    private String post(DfyBaseData dfyBaseData, String url) {

        DfyRequestBase dfyRequestBase = new DfyRequestBase(dfyBaseData);

        dfyRequestBase.setApiKey(apiKey);
        String signature = Signature.getSignature(JSONUtil.parseObj(dfyRequestBase), secretKey);
        dfyRequestBase.setSign(signature);

        String post = HttpUtil.post(host + url, JSONUtil.toJsonStr(dfyRequestBase));
        ApiLog apiLog = new ApiLog();
        apiLog.setSystem("Ticket");
        apiLog.setService(url);
        apiLog.setRequest(JSONUtil.toJsonStr(dfyRequestBase));
        apiLog.setResponse(JSONUtil.toJsonStr(post));
        apiLogDao.save(apiLog);
        return post;

    }


}
