package com.zswl.cloud.springBtach.server.core.api.ypp;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.json.JSONConfig;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.github.microservice.auth.security.helper.AuthHelper;
import com.github.microservice.auth.security.model.AuthDetails;
import com.zswl.cloud.springBatch.client.model.ypp.kfc.request.CreateOrdereRquest;
import com.zswl.cloud.springBatch.client.model.ypp.kfc.request.OrderListRequest;
import com.zswl.cloud.springBatch.client.model.ypp.kfc.response.*;
import com.zswl.cloud.springBtach.server.core.api.ypp.request.KfcGoodsDetailRequest;
import com.zswl.cloud.springBtach.server.core.api.ypp.request.KfcShopDetailRequest;
import com.zswl.cloud.springBtach.server.core.api.ypp.request.KfcShopsRequest;
import com.zswl.cloud.springBtach.server.core.dao.ApiLogDao;
import com.zswl.cloud.springBtach.server.core.helper.RedisHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.util.MultiValueMap;
import org.springframework.web.util.UriComponentsBuilder;

//接口地址 https://apifox.com/apidoc/shared-48c64918-c4ce-49f4-b846-d23855299d7a/doc-2590155
@Component
public class KfcApi {

    @Autowired
    TokenApi tokenApi;
    @Autowired
    RedisHelper redisHelper;


    @Autowired
    private ApiLogDao apiLogDao;


    @Value("${ypp.entId}")
    private String entId;
    @Value("${ypp.appSecret}")
    private String appSecret;

    @Value("${ypp.appId}")
    private String appId;
    @Value("${ypp.test}")
    private Boolean test;
    @Autowired
    private AuthHelper authHelper;


    /**
     * 订单上传文件列表
     *
     * @param orderId
     * @return
     */
    public OrderFileResponse order_files(String orderId) {
        String entries = tokenApi.httpGet("https://channel.youpiaopiao.cn/api/kfc/order_files?id=" + orderId);

        OrderFileResponse bean = JSONUtil.toBean(entries, OrderFileResponse.class);
        return bean;

    }

    /**
     * 订单详情
     *
     * @param orderId
     * @return
     */

    public OrderDetailResponse order_detail(String orderId) {
        String entries = tokenApi.httpGet("https://channel.youpiaopiao.cn/api/kfc/order_detail?id=" + orderId);

        OrderDetailResponse bean = JSONUtil.toBean(entries, OrderDetailResponse.class);
        return bean;

    }

    /**
     * 城市列表
     *
     * @return
     */
    public CityListResponse cityList() {
        String entries = tokenApi.httpGet("https://channel.youpiaopiao.cn/api/city/list");

        CityListResponse bean = JSONUtil.toBean(entries, CityListResponse.class);
        return bean;

    }

    /**
     * 支付订单(支付成功后调用)
     *
     * @param orderId
     * @return
     */
    public JSONObject pay_order(String orderId) {
        String entries = tokenApi.httpGet("https://channel.youpiaopiao.cn/api/kfc/pay_order?id=" + orderId + "&test=" + test);
        JSONConfig jsonConfig = JSONConfig.create();
        jsonConfig.setIgnoreError(true);
        return JSONUtil.parseObj(entries, jsonConfig);

    }

    /**
     * 下单(自己做产品展示，才需要下单接口)
     *
     * @param createOrdereRquest
     * @return
     */
    public CreateOrdereResponse create_order(CreateOrdereRquest createOrdereRquest) {
        createOrdereRquest.setAppId(appId);
        JSONObject entries = tokenApi.httpPost("https://channel.youpiaopiao.cn/api/kfc/create_order", createOrdereRquest);
        CreateOrdereResponse bean = JSONUtil.toBean(entries, CreateOrdereResponse.class);
        return bean;

    }


    /**
     * 订单列表
     *
     * @param orderListRequest
     * @return
     */
    public JSONObject order_list(OrderListRequest orderListRequest) {
        JSONObject entries = tokenApi.httpPost("https://channel.youpiaopiao.cn/api/kfc/order_list", orderListRequest);
        return entries;

    }

    /**
     * 平台店铺列表
     *
     * @param ot
     * @param cityId
     * @param lat
     * @param lon
     * @return
     */
    public ShopsResponse shops(KfcShopsRequest kfcShopsRequest) {
        String baseUrl = "https://channel.youpiaopiao.cn/api/kfc/shops";
        UriComponentsBuilder builder = UriComponentsBuilder.fromHttpUrl(baseUrl);
        builder.queryParam("ot", kfcShopsRequest.getOt());
        builder.queryParam("cityId", kfcShopsRequest.getCityId());

        if (ObjectUtil.isNotEmpty(kfcShopsRequest.getLat())) {
            builder.queryParam("lat", kfcShopsRequest.getLat());
        }
        if (ObjectUtil.isNotEmpty(kfcShopsRequest.getLon())) {
            builder.queryParam("lon", kfcShopsRequest.getLon());
        }
        String entries = tokenApi.httpGet(builder.build().toUriString());
        return JSONUtil.toBean(entries, ShopsResponse.class);

    }

    /**
     * 店铺详情，如果传了经纬度，返回距离
     *
     * @param id
     * @param lat
     * @param lon
     * @return
     */
    public ShopResponse shop(KfcShopDetailRequest kfcShopDetailRequest) {
        String baseUrl = "https://channel.youpiaopiao.cn/api/kfc/shop";

        UriComponentsBuilder builder = UriComponentsBuilder.fromHttpUrl(baseUrl);
        builder.queryParam("id", kfcShopDetailRequest.getId());

        if (ObjectUtil.isNotEmpty(kfcShopDetailRequest.getLat())) {
            builder.queryParam("lat", kfcShopDetailRequest.getLat());
        }
        if (ObjectUtil.isNotEmpty(kfcShopDetailRequest.getLon())) {
            builder.queryParam("lon", kfcShopDetailRequest.getLon());
        }
        String entries = tokenApi.httpGet(builder.build().toUriString());
        return JSONUtil.toBean(entries, ShopResponse.class);

    }

    /**
     * 菜单
     *
     * @param shopId
     * @return
     */
    public JSONObject menus(String shopId) {
        String baseUrl = "https://channel.youpiaopiao.cn/api/kfc/menus";

        UriComponentsBuilder builder = UriComponentsBuilder.fromHttpUrl(baseUrl);
        builder.queryParam("shopId", shopId);
        String entries = tokenApi.httpGet(builder.build().toUriString());
        JSONConfig jsonConfig = new JSONConfig();
        jsonConfig.setIgnoreError(true);
        return JSONUtil.parseObj(entries, jsonConfig);

    }

    /**
     * 商品详情(不同平台返回的商品详情不一致)
     *
     * @param shopId
     * @param productId
     * @return
     */
    public JSONObject goods_detail(KfcGoodsDetailRequest kfcGoodsDetailRequest) {
        String baseUrl = "https://channel.youpiaopiao.cn/api/kfc/goods_detail";

        UriComponentsBuilder builder = UriComponentsBuilder.fromHttpUrl(baseUrl);
        builder.queryParam("shopId", kfcGoodsDetailRequest.getShopId());
        builder.queryParam("productId", kfcGoodsDetailRequest.getProductId());
        String entries = tokenApi.httpGet(builder.build().toUriString());
        JSONConfig jsonConfig = new JSONConfig();
        jsonConfig.setIgnoreError(true);
        return JSONUtil.parseObj(entries, jsonConfig);

    }

    public String index() {
        AuthDetails currentUser = authHelper.getCurrentUser();
        String member_token = tokenApi.member_token(currentUser.getUserId(), currentUser.getPhone());
        String url = "https://www.youpiaopiao.cn/h10/#/pages/kfc/index?entid=" + entId + "&source=" + appId + "&token=" + member_token;

        return url;


    }


}
