package com.zswl.cloud.springBtach.server.core.api.ypp;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONConfig;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.zswl.cloud.springBatch.client.model.ypp.movie.request.CreateOrder2Request;
import com.zswl.cloud.springBatch.client.model.ypp.movie.request.CreateOrdereRquest;
import com.zswl.cloud.springBatch.client.model.ypp.movie.request.OrderListRequest;
import com.zswl.cloud.springBatch.client.model.ypp.movie.response.CreateOrdereResponse;
import com.zswl.cloud.springBatch.client.model.ypp.movie.response.OrderDetailResponse;
import com.zswl.cloud.springBatch.client.model.ypp.movie.response.CreateOrder2Response;
import com.zswl.cloud.springBtach.server.core.dao.ApiLogDao;
import com.zswl.cloud.springBtach.server.core.domain.ApiLog;
import com.zswl.cloud.springBtach.server.core.helper.RedisHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.util.Assert;
import org.springframework.web.util.UriComponentsBuilder;

import java.util.HashMap;

//接口地址 https://apifox.com/apidoc/shared-48c64918-c4ce-49f4-b846-d23855299d7a/doc-2590155
@Component
public class YppApi {

    @Autowired
    RedisHelper redisHelper;

    @Autowired
    TokenApi tokenApi;

    @Autowired
    private ApiLogDao apiLogDao;

    @Value("${ypp.entId}")
    private String entId;

    @Value("${ypp.appSecret}")
    private String appSecret;

    @Value("${ypp.appId}")
    private String appId;
    @Value("${ypp.test}")
    private Boolean test;


    private final String tokenName = "ypp-token";
    private final String tokenValue = "Bearer ";


    /**
     * 订单简要信息(字段较简洁，用于发起订单支付)
     *
     * @param orderId
     * @return
     */
    public OrderDetailResponse order_detail(String orderId) {
        String entries = tokenApi.httpGet("https://channel.youpiaopiao.cn/api/movie/order_detail?id=" + orderId);

        OrderDetailResponse bean = JSONUtil.toBean(entries, OrderDetailResponse.class);
        return bean;

    }

    /**
     * 支付订单(支付成功后调用)
     *
     * @param orderId
     * @return
     */
    public JSONObject pay_order(String orderId) {
        String entries = tokenApi.httpGet("https://channel.youpiaopiao.cn/api/movie/pay_order?id=" + orderId + "&test=" + test);
        JSONConfig jsonConfig = JSONConfig.create();
        jsonConfig.setIgnoreError(true);
        return JSONUtil.parseObj(entries, jsonConfig);

    }

    /**
     * 订单列表
     *
     * @param orderListRequest
     * @return
     */
    public JSONObject order_list(OrderListRequest orderListRequest) {
        JSONObject entries = tokenApi.httpPost("https://channel.youpiaopiao.cn/api/movie/list", orderListRequest);
        return entries;

    }

    /**
     * 订单详情
     *
     * @param orderId
     * @return
     */
    public JSONObject get_order(String orderId) {
        String entries = tokenApi.httpGet("https://channel.youpiaopiao.cn/api/movie/get_order?id=" + orderId);
        return JSONUtil.parseObj(entries);

    }

    /**
     * 创建订单 价格跟随有票票
     *
     * @param createOrdereRquest
     * @return
     */
    public CreateOrdereResponse create_order(CreateOrdereRquest createOrdereRquest) {
        createOrdereRquest.setAppId(appId);
        JSONObject entries = tokenApi.httpPost("https://channel.youpiaopiao.cn/api/movie/create_order", createOrdereRquest);
        CreateOrdereResponse bean = JSONUtil.toBean(entries, CreateOrdereResponse.class);
        return bean;

    }

    /**
     * 创建订单自定义价格
     *
     * @param createOrder2Request
     * @return
     */
    public CreateOrder2Response create_order2(CreateOrder2Request createOrder2Request) {
        createOrder2Request.setAppId(appId);
        createOrder2Request.setTest(test);
        JSONObject entries = tokenApi.httpPost("https://channel.youpiaopiao.cn/api/movie/create_order2", createOrder2Request);
        return JSONUtil.toBean(entries, CreateOrder2Response.class);

    }

    /**
     * 热映电影（pageIndex从0开始）
     *
     * @param
     * @return
     */
    public JSONObject movies(String cityId, String pageIndex, String pageSize) {
        String baseUrl = "https://channel.youpiaopiao.cn/api/movie/movies";

        UriComponentsBuilder builder = UriComponentsBuilder.fromHttpUrl(baseUrl);
        builder.queryParam("cityId", cityId);
        builder.queryParam("pageIndex", pageIndex);
        builder.queryParam("pageSize", pageSize);
        String entries = tokenApi.httpGet(builder.build().toUriString());
        JSONConfig jsonConfig = JSONConfig.create();
        jsonConfig.setIgnoreError(true);
        return JSONUtil.parseObj(entries, jsonConfig);

    }

    /**
     * 即将上映电影
     *
     * @param cityId
     * @return
     */
    public JSONObject coming_movies(String cityId) {
        String entries = tokenApi.httpGet("https://channel.youpiaopiao.cn/api/movie/coming_movies?cityId=" + cityId);
        JSONConfig jsonConfig = JSONConfig.create();
        jsonConfig.setIgnoreError(true);
        return JSONUtil.parseObj(entries, jsonConfig);

    }

    /**
     * 获取电影详情
     *
     * @param movieId
     * @return
     */
    public JSONObject movie_detail(String movieId) {
        String entries = tokenApi.httpGet("https://channel.youpiaopiao.cn/api/movie/movie_detail?movieId=" + movieId);
        JSONConfig jsonConfig = JSONConfig.create();
        jsonConfig.setIgnoreError(true);
        return JSONUtil.parseObj(entries, jsonConfig);

    }

    /**
     * 获取电影的影院列表
     *
     * @param movieId
     * @return
     */
    public JSONObject movie_cinemas(String cityId, String movieId, String day, String lat, String lng) {
        String baseUrl = "https://channel.youpiaopiao.cn/api/movie/movie_cinemas";

        UriComponentsBuilder builder = UriComponentsBuilder.fromHttpUrl(baseUrl);
        builder.queryParam("cityId", cityId);
        builder.queryParam("movieId", movieId);
        builder.queryParam("day", day);
        builder.queryParam("lat", lat);
        builder.queryParam("lng", lng);

        String entries = tokenApi.httpGet(builder.build().toUriString());
        JSONConfig jsonConfig = JSONConfig.create();
        jsonConfig.setIgnoreError(true);
        return JSONUtil.parseObj(entries, jsonConfig);

    }

    /**
     * 获取影院列表
     *
     * @param cityId
     * @param districtId
     * @param brandId
     * @param lat
     * @param lng
     * @return
     */

    public JSONObject cinemas(String cityId, String districtId, String brandId, String lat, String lng) {

        String baseUrl = "https://channel.youpiaopiao.cn/api/movie/cinemas";

        UriComponentsBuilder builder = UriComponentsBuilder.fromHttpUrl(baseUrl);
        builder.queryParam("cityId", cityId);
        builder.queryParam("districtId", districtId);
        builder.queryParam("brandId", brandId);
        builder.queryParam("cityId", cityId);
        if (ObjectUtil.isNotEmpty(lat)) {
            builder.queryParam("lat", lat);
        }
        if (ObjectUtil.isNotEmpty(lng)) {
            builder.queryParam("lng", lng);
        }
        String entries = tokenApi.httpGet(builder.build().toUriString());
        JSONConfig jsonConfig = JSONConfig.create();
        jsonConfig.setIgnoreError(true);
        return JSONUtil.parseObj(entries, jsonConfig);

    }

    /**
     * 获取影院过滤列表
     *
     * @param cityId
     * @return
     */
    public JSONObject cinema_filter(String cityId) {
        String entries = tokenApi.httpGet("https://channel.youpiaopiao.cn/api/movie/cinema_filter?cityId=" + cityId);
        JSONConfig jsonConfig = JSONConfig.create();
        jsonConfig.setIgnoreError(true);
        return JSONUtil.parseObj(entries, jsonConfig);

    }

    /**
     * 获取城市列表
     *
     * @return
     */
    public JSONObject get_citys() {
        String entries = tokenApi.httpGet("https://channel.youpiaopiao.cn/api/movie/get_citys");
        JSONConfig jsonConfig = JSONConfig.create();
        jsonConfig.setIgnoreError(true);
        return JSONUtil.parseObj(entries, jsonConfig);

    }


    /**
     * 获取影院某个电影的排片列表
     *
     * @param movieId
     * @param cinemaId
     * @return
     */
    public JSONObject cinema_shows(String movieId, String cinemaId) {
        String baseUrl = "https://channel.youpiaopiao.cn/api/movie/cinema_shows";
        UriComponentsBuilder builder = UriComponentsBuilder.fromHttpUrl(baseUrl);
        builder.queryParam("movieId", movieId);
        builder.queryParam("cinemaId", cinemaId);
        String entries = tokenApi.httpGet(builder.build().toUriString());
        JSONConfig jsonConfig = JSONConfig.create();
        jsonConfig.setIgnoreError(true);
        return JSONUtil.parseObj(entries, jsonConfig);
    }

    /**
     * 获取电影场次（座位）详情
     *
     * @param sessionId
     * @param cinemaId
     * @param movieId
     * @param sid
     * @return
     */
    public JSONObject session(String sessionId, String cinemaId, String movieId, String sid) {

        String baseUrl = "https://channel.youpiaopiao.cn/api/movie/session";

        UriComponentsBuilder builder = UriComponentsBuilder.fromHttpUrl(baseUrl);
        builder.queryParam("sessionId", sessionId);
        builder.queryParam("cinemaId", cinemaId);
        builder.queryParam("movieId", movieId);
        builder.queryParam("sid", sid);
        String entries = tokenApi.httpGet(builder.build().toUriString());
        JSONConfig jsonConfig = JSONConfig.create();
        jsonConfig.setIgnoreError(true);
        return JSONUtil.parseObj(entries, jsonConfig);
    }

    /**
     * 获取广告列表
     *
     * @return
     */
    public JSONObject ad_configs() {
        String entries = tokenApi.httpGet("https://channel.youpiaopiao.cn/api/movie/ad_configs");
        JSONConfig jsonConfig = JSONConfig.create();
        jsonConfig.setIgnoreError(true);
        return JSONUtil.parseObj(entries, jsonConfig);
    }


}
