package com.zswl.cloud.springBtach.server.core.controller;


import com.github.microservice.auth.client.constant.AuthConstant;
import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.security.annotations.ResourceAuth;
import com.github.microservice.auth.security.type.AuthType;
import com.zhongshu.payment.client.model.order.v2.CreatOrderResultModel;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.request.*;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.response.*;
import com.zswl.cloud.springBatch.client.service.DfyTicketService;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

@Log4j2
@RestController
@RequestMapping("dfy/ticket")
public class DfyTicketController {

    @Autowired
    DfyTicketService dfyTicketService;


    @ApiOperation(" 景点列表查询")
    @ResourceAuth(value = AuthConstant.User, type = AuthType.User)
    @RequestMapping(value = "scenicList", method = RequestMethod.POST, consumes = MediaType.APPLICATION_JSON_VALUE)
    ResultContent<ScenicListResponse> scenicList(@RequestBody ScenicListRequest scenicListRequest) {
        return dfyTicketService.scenicList(scenicListRequest);
    }


    @ApiOperation(" 景点详情接口")
    @ResourceAuth(value = AuthConstant.User, type = AuthType.User)
    @RequestMapping(value = "scenicDetail", method = RequestMethod.POST, consumes = MediaType.APPLICATION_JSON_VALUE)
    ResultContent<ScenicDetailResponse> scenicDetail(@RequestBody ScenicDetailRequest scenicDetailRequest) {
        return dfyTicketService.scenicDetail(scenicDetailRequest);
    }


    @ApiOperation(" 特权门票查询接口")
    @ResourceAuth(value = AuthConstant.User, type = AuthType.User)
    @RequestMapping(value = "privilegeTicketList", method = RequestMethod.POST, consumes = MediaType.APPLICATION_JSON_VALUE)
    ResultContent<PrivilegeTicketListResponse> privilegeTicketList(@RequestBody PrivilegeTicketListRequest privilegeTicketListRequest) {
        return dfyTicketService.privilegeTicketList(privilegeTicketListRequest);
    }


    @ApiOperation(" 门票详情接口")
    @ResourceAuth(value = AuthConstant.User, type = AuthType.User)
    @RequestMapping(value = "detail", method = RequestMethod.POST, consumes = MediaType.APPLICATION_JSON_VALUE)
    ResultContent<DetailResponse> detail(@RequestBody DetailRequest detailRequest) {
        return dfyTicketService.detail(detailRequest);
    }


    @ApiOperation(" 创建订单接口")
    @ResourceAuth(value = AuthConstant.User, type = AuthType.User)
    @RequestMapping(value = "createOrderNew", method = RequestMethod.POST, consumes = MediaType.APPLICATION_JSON_VALUE)
    ResultContent<CreatOrderResultModel> createOrderNew(@RequestBody @Valid CreateOrderNewRequest createOrderNewRequest) {
        return dfyTicketService.createOrderNew(createOrderNewRequest);
    }


    @ApiOperation(" 取消订单")
    @ResourceAuth(value = AuthConstant.User, type = AuthType.User)
    @RequestMapping(value = "cancelOrder", method = RequestMethod.POST, consumes = MediaType.APPLICATION_JSON_VALUE)
    ResultContent cancelOrder(@RequestBody CancelOrderRequest cancelOrderRequest) {
        return dfyTicketService.cancelOrder(cancelOrderRequest);
    }


    @ApiOperation(" 出票(代扣)接口")
    @ResourceAuth(value = AuthConstant.SuperAdmin, type = AuthType.Enterprise)
    @RequestMapping(value = "submitOrderResponse", method = RequestMethod.POST, consumes = MediaType.APPLICATION_JSON_VALUE)
    ResultContent<SubmitOrderResponse> submitOrderResponse(@RequestBody SubmitOrderRequest submitOrderRequest) {
        return dfyTicketService.submitOrderResponse(submitOrderRequest);
    }


    @ApiOperation(" 订单详情接口")
    @ResourceAuth(value = AuthConstant.User, type = AuthType.User)
    @RequestMapping(value = "orderDetail", method = RequestMethod.POST, consumes = MediaType.APPLICATION_JSON_VALUE)
    ResultContent<OrderDetailResponse> orderDetail(@RequestBody OrderDetailRequest orderDetailRequest) {
        return dfyTicketService.orderDetail(orderDetailRequest);
    }


    @ApiOperation(" 订单状态接口")
    @ResourceAuth(value = AuthConstant.User, type = AuthType.User)
    @RequestMapping(value = "orderStatus", method = RequestMethod.POST, consumes = MediaType.APPLICATION_JSON_VALUE)
    ResultContent<OrderStatusResponse> orderStatus(@RequestBody OrderStatusRequest orderStatusRequest) {
        return dfyTicketService.orderStatus(orderStatusRequest);
    }


    @ApiOperation(" 核销查询接口")
    @ResourceAuth(value = AuthConstant.User, type = AuthType.User)
    @RequestMapping(value = "verifyOrder", method = RequestMethod.POST, consumes = MediaType.APPLICATION_JSON_VALUE)
    ResultContent<VerifyOrderResponse> verifyOrder(@RequestBody VerifyOrderRequest verifyOrderRequest) {
        return dfyTicketService.verifyOrder(verifyOrderRequest);
    }


    @ApiOperation(" 退票申请接口")
    @ResourceAuth(value = AuthConstant.User, type = AuthType.User)
    @RequestMapping(value = "tuiPiao", method = RequestMethod.POST, consumes = MediaType.APPLICATION_JSON_VALUE)
    ResultContent<TuiPiaoResponse> tuiPiao(@RequestBody TuiPiaoRequest tuiPiaoRequest) {
        return dfyTicketService.tuiPiao(tuiPiaoRequest);
    }

    @ApiOperation(" 同步景区信息")
    @ResourceAuth(value = AuthConstant.SuperAdmin, type = AuthType.Platform)
    @RequestMapping(value = "sync", method = RequestMethod.POST, consumes = MediaType.APPLICATION_JSON_VALUE)
    void sync() {
        dfyTicketService.sync();
    }


}
