package com.zswl.cloud.springBtach.server.core.controller;

import com.github.microservice.auth.client.constant.AuthConstant;
import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.client.content.ResultState;
import com.github.microservice.auth.security.annotations.ResourceAuth;
import com.github.microservice.auth.security.helper.AuthHelper;
import com.github.microservice.auth.security.model.AuthDetails;
import com.github.microservice.auth.security.type.AuthType;
import com.xiaoju.open.oil.interfaces.domain.AllowancePromotionInfo;
import com.xiaoju.open.oil.interfaces.domain.GenPromotionInfo;
import com.xiaoju.open.oil.interfaces.domain.StorePriceInfo;
import com.xiaoju.open.oil.interfaces.request.QueryApiOrderListRequest;
import com.xiaoju.open.oil.interfaces.request.QueryGetPromotionRequest;
import com.xiaoju.open.oil.interfaces.response.*;
import com.zswl.cloud.springBatch.client.model.request.*;
import com.zswl.cloud.springBatch.client.model.xiaoju.ActivityModel;
import com.zswl.cloud.springBatch.client.model.xiaoju.QueryApiStorePriceRequest;
import com.zswl.cloud.springBtach.server.core.domain.XiaoJuActivity;
import com.zswl.cloud.springBtach.server.core.domain.XiaoJuStore;
import com.zswl.cloud.springBtach.server.core.service.impl.XiaoJuServiceImpl;
import io.swagger.annotations.ApiOperation;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@Log4j2
@RestController
@RequestMapping("xiaoju")
public class XiaoJuController {

    @Autowired
    XiaoJuServiceImpl xiaoJuService;

    @Autowired
    AuthHelper authHelper;

    @ApiOperation("查看附近的加油站信息")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "nearbyStore", method = RequestMethod.POST)
    public ResultContent<List<XiaoJuStoreModel>> nearbyStore(@RequestBody NearbyModel nearbyModel) {
        return xiaoJuService.nearbyStore(nearbyModel);
    }

    @ApiOperation("查询门店价格")
    @ResourceAuth(value = "user", type = AuthType.User)
    @RequestMapping(value = "queryStorePrice", method = RequestMethod.POST)
    public ResultContent<List<StorePriceInfo>> queryStorePrice(@RequestBody List<String> storeIdList) {

        QueryApiStorePriceRequest queryApiStorePriceRequest = new QueryApiStorePriceRequest();
        queryApiStorePriceRequest.setStoreIds(storeIdList);
        queryApiStorePriceRequest.setOutUserId(authHelper.getCurrentUser().getUserId());
        return xiaoJuService.queryStorePrice(queryApiStorePriceRequest);
    }

    @ApiOperation("查看加油站详情")
    @RequestMapping(value = "queryStoreDetail/{storeId}", method = RequestMethod.GET)
    @ResourceAuth(value = "user", type = AuthType.User)
    public ResultContent<XiaoJuStore> queryStoreDetail(@PathVariable("storeId") String storeId) {

        return xiaoJuService.queryStoreDetail(storeId);
    }

    @ApiOperation("查看加油站详情2-调用小橘接口")
    @RequestMapping(value = "queryStoreDetail2/{storeId}", method = RequestMethod.GET)
    @ResourceAuth(value = "user", type = AuthType.User)
    public ResultContent<XiaoJuStore> queryStoreDetail2(@PathVariable("storeId") String storeId) {

        return xiaoJuService.queryStoreDetail2(storeId);
    }

    @ApiOperation("价格计算")
    @RequestMapping(value = "queryCalPrice", method = RequestMethod.POST)
    @ResourceAuth(value = "user", type = AuthType.User)
    public ResultContent<QueryCalPriceResponse> queryCalPrice(@RequestBody QueryCalPriceModel queryCalPriceModel) {
        return xiaoJuService.queryCalPrice(queryCalPriceModel);
    }

    @ApiOperation("批量价格计算")
    @RequestMapping(value = "queryCalPrices", method = RequestMethod.POST)
    @ResourceAuth(value = "user", type = AuthType.User)
    public ResultContent<QueryCalBatchPriceResponse> queryCalPrices(@RequestBody QueryCalPricesModel queryCalPriceModel) {
        return xiaoJuService.queryCalPrices(queryCalPriceModel);
    }

    @ApiOperation("创建订单")
    @RequestMapping(value = "queryNewOrder", method = RequestMethod.POST)
    @ResourceAuth(value = "user", type = AuthType.User)
    public ResultContent<QueryNewOrderResponse> queryNewOrder(@RequestBody @Valid XiaoJuQueryNewOrderModel xiaoJuQueryNewOrderModel) {
        return xiaoJuService.queryNewOrder(xiaoJuQueryNewOrderModel);
    }

    @ApiOperation("取消订单")
    @RequestMapping(value = "cancelOrder", method = RequestMethod.POST)
    @ResourceAuth(value = "user", type = AuthType.User)
    public ResultContent cancelOrder(@RequestBody QueryNewOrderResponse queryNewOrderResponse) {
        return xiaoJuService.cancelOrder(queryNewOrderResponse);
    }

    @ApiOperation("查询订单列表")
    @RequestMapping(value = "queryOrderList", method = RequestMethod.POST)
    @ResourceAuth(value = "user", type = AuthType.User)
    public ResultContent queryOrderList(@RequestBody QueryApiOrderListRequest queryApiOrderListRequest) {
        QueryApiOrderListResponse queryApiOrderListResponse = xiaoJuService.queryOrderList(queryApiOrderListRequest);
        return ResultContent.build(ResultState.Success, queryApiOrderListResponse);
    }

    @ApiOperation("下单前查询最优可用券")
    @RequestMapping(value = "queryOrderPromotionList", method = RequestMethod.POST)
    @ResourceAuth(value = "user", type = AuthType.User)
    public ResultContent<List<AllowancePromotionInfo>> queryOrderPromotionList(@RequestBody XiaoJuQueryOrderPromotionListModel xiaoJuQueryOrderPromotionListModel) {
        ResultContent<List<AllowancePromotionInfo>> listResultContent = xiaoJuService.queryOrderPromotionList(xiaoJuQueryOrderPromotionListModel);
        return listResultContent;
    }

    @ApiOperation("查询多个门店可用券")
    @RequestMapping(value = "queryStorePromotionList", method = RequestMethod.POST)
    @ResourceAuth(value = "user", type = AuthType.User)
    public ResultContent<List<AllowancePromotionInfo>> queryStorePromotionList(@RequestBody List<String> storeIdList) {
        ResultContent<List<AllowancePromotionInfo>> listResultContent = xiaoJuService.queryStorePromotionList(storeIdList);
        return listResultContent;
    }

    @ApiOperation("查询用户所有券列表")
    @RequestMapping(value = "queryUserPromotionList", method = RequestMethod.POST)
    @ResourceAuth(value = "user", type = AuthType.User)
    public ResultContent<com.zswl.cloud.springBatch.client.model.xiaoju.QueryUserPromotionListResponse> queryUserPromotionList(@RequestBody XiaoJuQueryUserPromotionListModel xiaoJuQueryUserPromotionListModel) {
        AuthDetails currentUser = authHelper.getCurrentUser();
        xiaoJuQueryUserPromotionListModel.setMobile(currentUser.getPhone());
        xiaoJuQueryUserPromotionListModel.setOutUserId(currentUser.getUserId());
        ResultContent<com.zswl.cloud.springBatch.client.model.xiaoju.QueryUserPromotionListResponse> queryUserPromotionListResponseResultContent = xiaoJuService.queryUserPromotionList(xiaoJuQueryUserPromotionListModel);
        return queryUserPromotionListResponseResultContent;
    }

    @ApiOperation("券发放")
    @RequestMapping(value = "getPromotion/{activityId}", method = RequestMethod.GET)
    @ResourceAuth(value = AuthConstant.SuperAdmin, type = AuthType.Platform)
    public ResultContent<List<GenPromotionInfo>> getPromotion(@PathVariable("activityId") String activityId) {
        ResultContent<List<GenPromotionInfo>> listResultContent = xiaoJuService.getPromotion(activityId);
        return listResultContent;
    }


    @ApiOperation("添加活动")
    @RequestMapping(value = "addActivity", method = RequestMethod.POST)
    @ResourceAuth(value = AuthConstant.SuperAdmin, type = AuthType.Platform)
    public ResultContent<XiaoJuActivity> addActivity(@RequestBody ActivityModel activityModel) {
        return xiaoJuService.addActivity(activityModel);
    }


}
