package com.zswl.cloud.springBtach.server.core.job.dfy;

import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.client.content.ResultState;
import com.zhongshu.payment.client.model.order.v2.GoodsResultModel;
import com.zhongshu.payment.client.model.order.v2.OrderResult2Model;
import com.zhongshu.payment.client.model.order.v2.UpdateGoodsModel;
import com.zhongshu.payment.client.model.payment.SubOrdersConfirmResponseModel;
import com.zhongshu.payment.client.service.v2.OrderService2;
import com.zhongshu.payment.client.service.v2.PaymentService2;
import com.zhongshu.payment.client.type.OrderType;
import com.zswl.cloud.springBatch.client.model.dfy.Hotel.request.OrderDetailRequest;
import com.zswl.cloud.springBatch.client.model.dfy.Hotel.request.SubmitOrderRequest;
import com.zswl.cloud.springBatch.client.model.dfy.Hotel.response.AddOrderResponse;
import com.zswl.cloud.springBatch.client.model.dfy.Hotel.response.OrderDetailResponse;
import com.zswl.cloud.springBatch.client.model.dfy.Hotel.response.SubmitOrderResponse;
import com.zswl.cloud.springBtach.server.core.api.dfy.DomesticHotelApi;
import com.zswl.cloud.springBtach.server.core.job.standard.StandarDeliveryJob;
import lombok.Data;
import lombok.experimental.Delegate;
import lombok.extern.log4j.Log4j2;
import org.springframework.batch.core.Job;
import org.springframework.batch.core.Step;
import org.springframework.batch.core.launch.support.RunIdIncrementer;
import org.springframework.batch.repeat.RepeatStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.math.BigDecimal;

@Data
@Log4j2
@Configuration
public class HotelDeliveryJob {

    @Autowired
    @Delegate
    StandarDeliveryJob standarDeliveryJob;


    @Autowired
    OrderService2 orderService2;

    @Autowired
    PaymentService2 paymentService2;

    @Autowired
    DomesticHotelApi domesticHotelApi;

    @Value("${dfy.payType}")
    private Integer payType;


    public Step hotelDeliveryStep() {
        return getStepBuilderFactory().get("hotelDeliveryStep")
                .tasklet((contribution, chunkContext) -> {
                    GoodsResultModel goodsResultModel = getParameter().get();
                    ResultContent<OrderResult2Model> goodsResultModelResultContent = orderService2.orderInfo(goodsResultModel.getOrderNo());
                    BigDecimal payAmount = goodsResultModelResultContent.getContent().getPayAmount();

                    JSONObject extend = goodsResultModel.getExtend();
                    AddOrderResponse.Datas bean = JSONUtil.toBean(extend, AddOrderResponse.Datas.class);


                    SubmitOrderRequest submitOrderRequest = new SubmitOrderRequest();
                    submitOrderRequest.setOrderId(bean.getOrderId());
                    submitOrderRequest.setPayType(payType);
                    submitOrderRequest.setPay(String.valueOf(payAmount));

                    SubmitOrderResponse submitOrderResponse = domesticHotelApi.submitOrder(submitOrderRequest);


                    extend.set("response", submitOrderResponse);
                    if (!submitOrderResponse.getSuccess()) {
                        UpdateGoodsModel updateGoodsModel = new UpdateGoodsModel();
                        updateGoodsModel.setId(goodsResultModel.getId());
                        updateGoodsModel.setVerifyModel(extend);
                        orderService2.updateGoods(updateGoodsModel);
                        return RepeatStatus.FINISHED;
                    }

                    // 分账
                    ResultContent<SubOrdersConfirmResponseModel> subOrdersConfirmResponseModelResultContent = paymentService2.subOrdersConfirm(goodsResultModel.getId(), goodsResultModel.getShopId());
                    if (!subOrdersConfirmResponseModelResultContent.getState().equals(ResultState.Success)) {
                        log.info("分账失败：{}", JSONUtil.toJsonStr(goodsResultModel));
                        getResultContent().set(ResultContent.build(ResultState.Fail));
                    }

                    OrderDetailRequest orderDetailRequest = new OrderDetailRequest();
                    orderDetailRequest.setOrderId(bean.getOrderId());
                    OrderDetailResponse orderDetailResponse = domesticHotelApi.orderDetail(orderDetailRequest);
                    JSONObject entries = JSONUtil.parseObj(extend);
                    entries.put("orderInfo", orderDetailResponse.getData().getOrderInfo());

                    UpdateGoodsModel updateGoodsModel = new UpdateGoodsModel();
                    updateGoodsModel.setId(goodsResultModel.getId());
                    updateGoodsModel.setDelivery(true);
                    updateGoodsModel.setExtend(entries);
                    updateGoodsModel.setGoodsState(OrderType.WAIT_USE);
                    orderService2.updateGoods(updateGoodsModel);

                    getResultContent().set(ResultContent.build(ResultState.Success));
                    return RepeatStatus.FINISHED;

                })
                .build();
    }

    @Bean
    public Job hotelDelivery() {
        return getJobBuilderFactory()
                .get("hotelDelivery")
                .start(hotelDeliveryStep())
                .incrementer(new RunIdIncrementer())
                .build();
    }

}

