package com.zswl.cloud.springBtach.server.core.job.video;

import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.client.content.ResultState;
import com.zhongshu.payment.client.model.order.v2.GoodsResultModel;
import com.zhongshu.payment.client.model.order.v2.UpdateGoodsModel;
import com.zhongshu.payment.client.model.order.v2.VerificationModel;
import com.zhongshu.payment.client.model.payment.SubOrdersConfirmResponseModel;
import com.zhongshu.payment.client.service.v2.OrderService2;
import com.zhongshu.payment.client.service.v2.PaymentService2;
import com.zhongshu.payment.client.type.OrderType;
import com.zswl.cloud.shop.client.service.GoodsService;
import com.zswl.cloud.shop.client.service.ShopService;
import com.zswl.cloud.shop.client.vo.life.ShopDetailVo;
import com.zswl.cloud.springBtach.server.core.api.video.YqdCreateRequestModel;
import com.zswl.cloud.springBtach.server.core.api.video.YqdServiceImpl;
import com.zswl.cloud.springBtach.server.core.job.standard.StandarDeliveryJob;
import lombok.Data;
import lombok.experimental.Delegate;
import lombok.extern.log4j.Log4j2;
import org.springframework.batch.core.Job;
import org.springframework.batch.core.Step;
import org.springframework.batch.core.launch.support.RunIdIncrementer;
import org.springframework.batch.repeat.RepeatStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.util.List;

@Data
@Log4j2
@Configuration
public class VideoDeliveryJob {

    @Autowired
    @Delegate
    StandarDeliveryJob standarDeliveryJob;

    @Autowired
    GoodsService goodsService;

    @Autowired
    OrderService2 orderService2;

    @Autowired
    PaymentService2 paymentService2;

    @Autowired
    YqdServiceImpl yqdServiceImpl;

    @Autowired
    ShopService shopService;


    public Step videoDeliveryStep() {
        return getStepBuilderFactory().get("videoDeliveryStep")
                .tasklet((contribution, chunkContext) -> {
                    GoodsResultModel goodsResultModel = getParameter().get();

                    JSONObject entries = JSONUtil.parseObj(goodsResultModel.getExtend());
                    String account = String.valueOf(entries.get("account"));



                    // 调用三方充值
                    YqdCreateRequestModel createRequestModel = new YqdCreateRequestModel();
                    createRequestModel.setBuyCount(1);
                    createRequestModel.setExternal_orderno(goodsResultModel.getId());
                    createRequestModel.setCommodityId(goodsResultModel.getGoodsId());
                    createRequestModel.setTemplate(List.of(account));
                    createRequestModel.setExternalSellPrice(goodsResultModel.getPayAmount());
                    createRequestModel.setRemark(goodsResultModel.getUserId());
                    ResultContent yqdServiceImpl2 = yqdServiceImpl.create2(createRequestModel);
                    log.info("视频会员响应结果：{}", yqdServiceImpl2.getContent());
                    if (!yqdServiceImpl2.getState().equals(ResultState.Success)) {
                        getResultContent().set(ResultContent.build(ResultState.Fail));
                        return RepeatStatus.FINISHED;
                    }

                    // 分账
                    ResultContent<SubOrdersConfirmResponseModel> subOrdersConfirmResponseModelResultContent = paymentService2.subOrdersConfirm(goodsResultModel.getId(), goodsResultModel.getShopId());
                    if (!subOrdersConfirmResponseModelResultContent.getState().equals(ResultState.Success)){
                        log.info("分账失败：{}",JSONUtil.toJsonStr(goodsResultModel));
                        getResultContent().set(ResultContent.build(ResultState.Fail));
                        return RepeatStatus.FINISHED;
                    }

                    com.zswl.cloud.shop.client.ret.ResultContent<ShopDetailVo> detail = shopService.detail(goodsResultModel.getShopId());

                    VerificationModel verificationModel = new VerificationModel();
                    verificationModel.setId(goodsResultModel.getId());
                    verificationModel.setShopId(goodsResultModel.getShopId());
                    verificationModel.setShopName(detail.getContent().getShopName());
                    verificationModel.setCheckTime(System.currentTimeMillis());
                    verificationModel.setEmployeeName("系统");
                    Object goodsName = JSONUtil.parseObj(goodsResultModel.getGoodsInfo()).get("goodsName");
                    verificationModel.setGoodsName(String.valueOf(goodsName));


                    JSONObject entries1 =goodsResultModel.getExtend();
                    entries1.set("create", yqdServiceImpl2.getContent());

                    UpdateGoodsModel updateGoodsModel = new UpdateGoodsModel();
                    updateGoodsModel.setId(goodsResultModel.getId());
                    updateGoodsModel.setDelivery(true);
                    updateGoodsModel.setVerifyModel(entries1);
                    updateGoodsModel.setGoodsState(OrderType.USED);
                    updateGoodsModel.setVerifyModel(JSONUtil.parseObj(verificationModel));
                    orderService2.updateGoods(updateGoodsModel);

                    getResultContent().set(ResultContent.build(ResultState.Success));
                    return RepeatStatus.FINISHED;

                })
                .build();
    }

    @Bean
    public Job videoDelivery() {
        return getJobBuilderFactory()
                .get("videoDelivery")
                .start(videoDeliveryStep())
                .incrementer(new RunIdIncrementer())
                .build();
    }

}

