package com.zswl.cloud.springBtach.server.core.job.video;

import cn.hutool.json.JSONUtil;
import com.github.microservice.auth.client.content.ResultContent;
import com.zhongshu.payment.client.model.order.v2.CreateOrder2Model;
import com.zhongshu.payment.client.type.TransferOwner;
import com.zhongshu.payment.client.type.TransferType;
import com.zswl.cloud.shop.client.service.ShopService;
import com.zswl.cloud.shop.client.vo.life.GoodsInfoVo;
import com.zswl.cloud.shop.client.vo.life.SharePlatformVo;
import com.zswl.cloud.springBtach.server.core.job.standard.StandarOrderJob;
import lombok.Data;
import lombok.experimental.Delegate;
import lombok.extern.log4j.Log4j2;
import org.springframework.batch.core.Job;
import org.springframework.batch.core.Step;
import org.springframework.batch.core.launch.support.RunIdIncrementer;
import org.springframework.batch.repeat.RepeatStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.math.BigDecimal;
import java.util.ArrayList;

@Data
@Log4j2
@Configuration
public class VideoOrderJob {
    @Autowired
    @Delegate
    StandarOrderJob standarOrderJob;

    @Autowired
    ShopService shopService;

    public Step videoOrderStep() {
        return getStepBuilderFactory().get("videoOrderStep").tasklet((it, ii) -> {

            CreateOrder2Model orderParamModel = getParameter().get();

            for (CreateOrder2Model.Goods goods : orderParamModel.getGoodsList()) {
                com.zswl.cloud.shop.client.ret.ResultContent resultContent = shopService.goodsInfo(orderParamModel.getShopId(),goods.getGoodsId(), orderParamModel.getUserId());


                Object o = JSONUtil.parseObj(resultContent.getContent()).get("goods");

                GoodsInfoVo goodsInfoVo = JSONUtil.toBean(JSONUtil.toJsonStr(o),GoodsInfoVo.class);

                log.info("转换后的goodsInfoVo：{}",JSONUtil.toJsonStr(goodsInfoVo));

                // 计算价格
                goods.setPayAmount(goodsInfoVo.getRealPrice());

                SharePlatformVo sharePlatformVo = goodsInfoVo.getSharePlatformVo();


                orderParamModel.setTotalAmount(goodsInfoVo.getRealPrice());
                orderParamModel.setPayAmount(goodsInfoVo.getRealPrice());
                orderParamModel.setDiscountAmount(BigDecimal.ZERO);


                goods.setValidDay(goodsInfoVo.getValidDay());



                // 设置分账规则
                goods.setTransferType(sharePlatformVo.getShareType() == 1 ? TransferType.RATIO : TransferType.FIXED);
                // 平台
                CreateOrder2Model.Owner platform = new CreateOrder2Model.Owner();
                platform.setOwner(TransferOwner.PLATFORM);
                platform.setValue(sharePlatformVo.getPlatformRate());

                // 购买店铺
                CreateOrder2Model.Owner byShop = new CreateOrder2Model.Owner();
                byShop.setOwner(TransferOwner.BUY_SHOP);
                byShop.setValue(sharePlatformVo.getBuyShopRate());

                // 使用店铺
                CreateOrder2Model.Owner useShop = new CreateOrder2Model.Owner();
                useShop.setOwner(TransferOwner.USE_SHOP);
                useShop.setValue(sharePlatformVo.getCheckShopRate());

                ArrayList<CreateOrder2Model.Owner> rule = new ArrayList<>();
                rule.add(platform);
                rule.add(byShop);
                rule.add(useShop);
                goods.setTransferRrule(rule);

                // 设置商品详情
                goods.setGoodsInfo(JSONUtil.parseObj(goodsInfoVo));

                log.info("请求参数：{}",JSONUtil.toJsonStr(orderParamModel));
                ResultContent creat = getOrderService2().creat(orderParamModel);
                getResultContent().set(creat);
                return RepeatStatus.FINISHED;

            }
            return RepeatStatus.FINISHED;
        }).build();

    }


    @Bean
    public Job videoOrder() {
        return getJobBuilderFactory()
                .get("videoOrder")
                .start(videoOrderStep())
                .incrementer(new RunIdIncrementer())
                .build();
    }
}
