package com.zswl.cloud.springBtach.server.core.publish;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.github.microservice.productcenter.client.model.LocationModel;
import com.github.microservice.productcenter.client.model.ProductPushModel;
import com.github.microservice.productcenter.client.model.ProductTriggerTaskModel;
import com.github.microservice.productcenter.client.model.RegionModel;
import com.github.microservice.productcenter.client.publish.ProductPublish;
import com.github.microservice.productcenter.client.service.ProductPushService;
import com.github.microservice.productcenter.client.stream.ProductCenterStream;
import com.github.microservice.productcenter.client.type.ProductType;
import com.github.microservice.productcenter.client.type.RegionType;
import com.zswl.cloud.springBtach.server.core.api.ypp.YppApi;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

@Slf4j
@Component
public class CinemaPublish implements ProductPublish {

    @Autowired
    private ProductCenterStream productCenterStream;

    @Autowired
    YppApi yppApi;

    @Override
    public String regionCode() {
        return null;
    }

    @Override
    public Collection<RegionType> regionType() {
        return Set.of(RegionType.City);
    }

    @Override
    public Collection<ProductType> productTypes() {
        return Set.of(
                ProductType.Cinema
        );
    }


    @Override
    public void trigger(ProductPushService updateService, ProductTriggerTaskModel productTriggerTask) {

        JSONObject citys = yppApi.get_citys();
        JSONArray byPath = (JSONArray) citys.getByPath("data");
        Map<String, String> collect = byPath.stream().collect(Collectors.toMap(it -> JSONUtil.parseObj(it).get("name").toString(), it -> JSONUtil.parseObj(it).get("cityId").toString()));
//

        RegionModel region = productTriggerTask.getRegion();
        String name = region.getName();
        String s = collect.get(name);
        if (ObjectUtil.isEmpty(s)) {
            throw new RuntimeException("地区信息不匹配");
        }
        JSONObject entries = yppApi.cinemas(s, null, null, null, null);
        JSONArray data = (JSONArray) entries.getByPath("data");
        data.forEach(it -> {
            try {
                JSONObject entry = JSONUtil.parseObj(it);
                System.out.println(entry);
                String cinemaCode = entry.get("cinemaCode").toString();
                String names = entry.get("name").toString();
                BigDecimal lng = (BigDecimal) entry.get("lng");
                BigDecimal lat = (BigDecimal) entry.get("lat");
                String address = entry.get("address").toString();
                BigDecimal bigDecimal = new BigDecimal(entry.get("sellPrice").toString());
                Long sellPrice = bigDecimal.multiply(BigDecimal.valueOf(100)).longValue();
                LocationModel locationModel = new LocationModel();
                locationModel.setLongitude(lng.doubleValue());
                locationModel.setLatitude(lat.doubleValue());

                productCenterStream.send(List.of(
                        ProductPushModel.builder()
                                .regionCode(productTriggerTask.getRegion().getCode())
                                .pid(cinemaCode)
                                .productType(ProductType.Cinema)
                                .title(names)
                                .address(address)
                                .salePrice(sellPrice)
                                .locationPoint(locationModel)
                                .meta(Map.of("cinemas", entry))
                                .build()
                ));
            } catch (Exception e) {
                e.printStackTrace();
            }

        });


    }
}
