package com.zswl.cloud.springBtach.server.core.publish;

import cn.hutool.core.util.ObjectUtil;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.github.microservice.productcenter.client.model.ProductPushModel;
import com.github.microservice.productcenter.client.model.ProductTriggerTaskModel;
import com.github.microservice.productcenter.client.model.RegionModel;
import com.github.microservice.productcenter.client.publish.ProductPublish;
import com.github.microservice.productcenter.client.service.ProductPushService;
import com.github.microservice.productcenter.client.stream.ProductCenterStream;
import com.github.microservice.productcenter.client.type.ProductType;
import com.github.microservice.productcenter.client.type.RegionType;
import com.zswl.cloud.springBtach.server.core.api.ypp.YppApi;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

@Slf4j
@Component
public class ComingMoviePublish implements ProductPublish {

    @Autowired
    YppApi yppApi;

    @Autowired
    private ProductCenterStream productCenterStream;

    @Override
    public String regionCode() {
        return null;
    }

    @Override
    public Collection<RegionType> regionType() {
        return Set.of(RegionType.City);
    }

    @Override
    public Collection<ProductType> productTypes() {
        return Set.of(
                ProductType.MovieTicket
        );
    }


    @Override
    public void trigger(ProductPushService updateService, ProductTriggerTaskModel productTriggerTask) {

//        var cityId = productTriggerTask.getScheduledTask().getParameter().get("cityId");

        JSONObject citys = yppApi.get_citys();
        JSONArray byPath = (JSONArray) citys.getByPath("data");
        Map<String, String> collect = byPath.stream().collect(Collectors.toMap(it -> JSONUtil.parseObj(it).get("name").toString(), it -> JSONUtil.parseObj(it).get("cityId").toString()));
//

        RegionModel region = productTriggerTask.getRegion();
        String name = region.getName();
        String s = collect.get(name);
        if (ObjectUtil.isEmpty(s)) {
            throw new RuntimeException("地区信息不匹配");
        }


        JSONObject entries = yppApi.coming_movies(s);
        JSONArray movies = (JSONArray) entries.getByPath("data.movies");
        if (movies.isEmpty()) {
            return;
        }

        movies.forEach(it -> {
            try {
                JSONObject entry = JSONUtil.parseObj(it);
                System.out.println(entry);
                String movieName = entry.get("name").toString();
                String movieCode = entry.get("movieCode").toString();
                String posterUrl = entry.get("posterUrl").toString();
                productCenterStream.send(List.of(ProductPushModel.builder()
                        .regionCode(productTriggerTask.getRegion().getCode())
                        .pid(ObjectUtil.isEmpty(movieCode) ? entry.get("movieId").toString() : movieCode)
                        .productType(ProductType.MovieTicket)
                        .cover(new String[]{posterUrl})
                        .title(movieName)
                        .meta(Map.of("movies", entry))
                        .expireTimeSecond(60 * 60 * 24)
                        .build()));
            } catch (Exception e) {
                e.printStackTrace();
            }

        });


    }
}
