package com.zswl.cloud.springBtach.server.core.publish;

import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.productcenter.client.model.LocationModel;
import com.github.microservice.productcenter.client.model.ProductPushModel;
import com.github.microservice.productcenter.client.model.ProductTriggerTaskModel;
import com.github.microservice.productcenter.client.model.RegionModel;
import com.github.microservice.productcenter.client.publish.ProductPublish;
import com.github.microservice.productcenter.client.service.ProductPushService;
import com.github.microservice.productcenter.client.stream.ProductCenterStream;
import com.github.microservice.productcenter.client.type.ProductType;
import com.github.microservice.productcenter.client.type.RegionType;
import com.xiaoju.open.oil.interfaces.domain.StorePriceInfo;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.request.ScenicListRequest;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.response.ScenicListResponse;
import com.zswl.cloud.springBatch.client.model.xiaoju.QueryApiStorePriceRequest;
import com.zswl.cloud.springBtach.server.core.api.dfy.TicketApi;
import com.zswl.cloud.springBtach.server.core.dao.XiaoJuStoreDao;
import com.zswl.cloud.springBtach.server.core.domain.XiaoJuStore;
import com.zswl.cloud.springBtach.server.core.service.impl.XiaoJuServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.*;
import java.util.stream.Collectors;

@Slf4j
@Component
public class PetrolStationPublish implements ProductPublish {


    @Autowired
    XiaoJuStoreDao xiaoJuStoreDao;

    @Autowired
    XiaoJuServiceImpl xiaoJuService;

    @Autowired
    private ProductCenterStream productCenterStream;

    @Override
    public String regionCode() {
        return null;
    }

    @Override
    public Collection<RegionType> regionType() {
        return Set.of(RegionType.City);
    }

    @Override
    public Collection<ProductType> productTypes() {
        return Set.of(
                ProductType.PetrolStation
        );
    }


    @Override
    public void trigger(ProductPushService updateService, ProductTriggerTaskModel productTriggerTask) {


        RegionModel region = productTriggerTask.getRegion();
        String name = region.getName();

        xiaoJuStoreDao.findByCityNameContains(name).forEach(it -> {

            try {
                List<Integer> collect = it.getItemInfoList().stream().map(itemPriceInfo -> itemPriceInfo.getVipPrice()).collect(Collectors.toList());
                if (collect.isEmpty()) {
                    QueryApiStorePriceRequest queryApiStorePriceRequest = new QueryApiStorePriceRequest();
                    queryApiStorePriceRequest.setStoreIds(List.of(it.getStoreId()));
                    queryApiStorePriceRequest.setOutUserId("pSdqnnUiqQxiWHg2zmnesevap6s");
                    ResultContent<XiaoJuStore> xiaoJuStoreResultContent = xiaoJuService.queryStoreDetail(it.getStoreId());

                    collect = xiaoJuStoreResultContent.getContent().getItemInfoList().stream().map(itemPriceInfo -> itemPriceInfo.getVipPrice()).collect(Collectors.toList());
                }
                if (collect.isEmpty()) {
                    return;
                }

                Integer min = Collections.min(collect);
                LocationModel locationModel = new LocationModel();
                locationModel.setLongitude(it.getLon());
                locationModel.setLatitude(it.getLat());
                productCenterStream.send(List.of(
                        ProductPushModel.builder()
                                .regionCode(productTriggerTask.getRegion().getCode())
                                .pid(it.getStoreId())
                                .productType(ProductType.PetrolStation)
                                .cover(it.getPicList().stream().toArray(String[]::new))
                                .title(it.getStoreName())
                                .address(it.getAddress())
                                .salePrice(Long.valueOf(min))
                                .meta(Map.of("store", it))
                                .locationPoint(locationModel)
                                .build()));
            } catch (Exception e) {
                log.info("错误店铺：{}", it);
                e.printStackTrace();
            }

        });


    }


}
