package com.zswl.cloud.springBtach.server.core.publish;

import cn.hutool.core.util.ObjectUtil;
import com.github.microservice.productcenter.client.model.LocationModel;
import com.github.microservice.productcenter.client.model.ProductPushModel;
import com.github.microservice.productcenter.client.model.ProductTriggerTaskModel;
import com.github.microservice.productcenter.client.model.RegionModel;
import com.github.microservice.productcenter.client.publish.ProductPublish;
import com.github.microservice.productcenter.client.service.ProductPushService;
import com.github.microservice.productcenter.client.stream.ProductCenterStream;
import com.github.microservice.productcenter.client.type.ProductType;
import com.github.microservice.productcenter.client.type.RegionType;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.request.ScenicListRequest;
import com.zswl.cloud.springBatch.client.model.dfy.Ticket.response.ScenicListResponse;
import com.zswl.cloud.springBtach.server.core.api.dfy.TicketApi;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;

@Slf4j
@Component
public class TicketPublish implements ProductPublish {

    @Autowired
    TicketApi ticketApi;

    @Autowired
    private ProductCenterStream productCenterStream;

    @Override
    public String regionCode() {
        return null;
    }

    @Override
    public Collection<RegionType> regionType() {
        return Set.of(RegionType.City);
    }

    @Override
    public Collection<ProductType> productTypes() {
        return Set.of(
                ProductType.Scenic
        );
    }


    @Override
    public void trigger(ProductPushService updateService, ProductTriggerTaskModel productTriggerTask) {


        RegionModel region = productTriggerTask.getRegion();
        String name = region.getName();

        int page = 1;
        while (true) {
            ScenicListRequest scenicListRequest = new ScenicListRequest();
            scenicListRequest.setPage(page);
            scenicListRequest.setPageSize(10);
            scenicListRequest.setKey(name);
            ScenicListResponse scenicListResponse = ticketApi.scenicList(scenicListRequest);

            List<ScenicListResponse.rows> rows = scenicListResponse.getData().getRows();

            if (ObjectUtil.isEmpty(rows)) {
                return;
            }
            rows.forEach(it -> {
                List<Long> collect = it.getTicketList().stream().map(item -> new BigDecimal(item.getSalePrice()).multiply(BigDecimal.valueOf(100)).longValue()).collect(Collectors.toList());
                Long min = Collections.min(collect);

                try {
                    LocationModel locationModel = new LocationModel();
                    String glocation = it.getGlocation();
                    if (ObjectUtil.isNotEmpty(glocation)) {
                        String[] split = glocation.split(",");

                        locationModel.setLatitude(Double.parseDouble(split[0]));
                        locationModel.setLongitude(Double.parseDouble(split[1]));
                    }
                    productCenterStream.send(List.of(
                            ProductPushModel.builder()
                                    .regionCode(productTriggerTask.getRegion().getCode())
                                    .pid(it.getScenicId())
                                    .productType(ProductType.Scenic)
                                    .cover(new String[]{it.getNewPicUrl()})
                                    .title(it.getScenicName())
                                    .address(it.getAddress())
                                    .salePrice(min)
                                    .meta(Map.of("scenic", it))
                                    .locationPoint(locationModel)
                                    .build()));
                } catch (Exception e) {
                    e.printStackTrace();
                }


            });

            page++;

        }


    }
}
