package com.zswl.cloud.springBtach.server.core.service;

import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.security.helper.AuthHelper;
import com.github.microservice.auth.security.model.AuthDetails;
import com.zhongshu.payment.client.model.*;
import com.zhongshu.payment.client.model.order.AdminSeachOrderModel;
import com.zhongshu.payment.client.model.order.v2.*;
import com.zhongshu.payment.client.model.payment.QueryResponseModel;
import com.zhongshu.payment.client.model.payment.zswl.*;
import com.zhongshu.payment.client.service.v2.OrderService2;
import com.zhongshu.payment.client.service.v2.PaymentService2;
import com.zhongshu.payment.client.type.Channel;
import com.zhongshu.payment.client.type.JobFlowMap;
import com.zhongshu.payment.client.type.JobFlowType;
import com.zswl.cloud.springBtach.server.core.job.standard.StandarPayJob;
import lombok.SneakyThrows;
import org.springframework.batch.core.Job;
import org.springframework.batch.core.JobParameters;
import org.springframework.batch.core.JobParametersBuilder;
import org.springframework.batch.core.explore.JobExplorer;
import org.springframework.batch.core.launch.JobLauncher;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

@Service
public class PaymentService {


    @Autowired
    PaymentService2 paymentService2;

    @Autowired
    AuthHelper authHelper;

    @Autowired
    OrderService2 orderService2;

    @Autowired
    private StandarPayJob standarPayJob;

    @Autowired
    private ApplicationContext applicationContext;

    @Resource
    private JobExplorer jobExplorer;

    @Resource
    private JobLauncher jobLauncher;


    @SneakyThrows
    public ResultContent creatPayOrder(CreatePaymentModel createPaymentModel) {
        CreatePayment2Model createPayment2Model = new CreatePayment2Model();
        BeanUtils.copyProperties(createPaymentModel, createPayment2Model);
        createPayment2Model.setAuthUserId(authHelper.getCurrentUser().getUserId());

        ResultContent<List<GoodsResultModel>> listResultContent = orderService2.goodsDetail(createPaymentModel.getOrderNo());
        JobFlowMap jobFlowMap = listResultContent.getContent().get(0).getJobFlowMap();
        String jobName = jobFlowMap.getJobMapping().get(JobFlowType.CratePlayOrder);
        ThreadLocal<CreatePayment2Model> parameter = standarPayJob.getParameter();
        parameter.set(createPayment2Model);
        Job job = (Job) applicationContext.getBean(jobName);
        JobParameters parameters = new JobParametersBuilder(jobExplorer)
                .getNextJobParameters(job)
                .addLong("time", System.currentTimeMillis()).toJobParameters();
        jobLauncher.run(job, parameters).getExitStatus();
        return standarPayJob.getResultContent().get();
    }

    public ResultContent query(String orderNo) {

        String userId = authHelper.getCurrentUser().getUserId();
        ResultContent<QueryResponseModel> query = paymentService2.query(userId, orderNo);
        return query;
    }

    public ResultContent applicantRefund(ApplicantRefundParam2Model applicantRefundParam2Model) {

        String userId = authHelper.getCurrentUser().getUserId();
        applicantRefundParam2Model.setUserId(userId);
        return paymentService2.refundSelect(applicantRefundParam2Model);
    }

    public ResultContent refundIntervene(String goodsId) {
        String userId = authHelper.getCurrentUser().getUserId();
        return paymentService2.refundIntervene(userId, goodsId);
    }


    public ResultContent unRefund(ApplicantRefundParam2Model applicantRefundParam2Model) {
        String userId = authHelper.getCurrentUser().getUserId();
        applicantRefundParam2Model.setUserId(userId);
        return paymentService2.unRefund(applicantRefundParam2Model);
    }

    public ResultContent auditRefund(RefundParam2Model refundParam2Model) {
        return paymentService2.auditRefund(refundParam2Model);
    }

    public ResultContent close(String orderNo) {
        String userId = authHelper.getCurrentUser().getUserId();
        return paymentService2.close(orderNo, userId);
    }

    public ResultContent transfer(String id) {
        return paymentService2.transfer(id);
    }

    public ResultContent transferList(AdminSeachOrderModel seachOrderModel) {
        String enterPriseId = authHelper.getEnterPriseId();
        seachOrderModel.setShopId(enterPriseId);
        return paymentService2.transferList(seachOrderModel);
    }

    public ResultContent getDetail() {
        return paymentService2.getDetail(authHelper.getEnterPriseId());
    }

    public ResultContent platformDetail(Channel channel) {
        return paymentService2.getDetail(channel.name());
    }

    public ResultContent applicationShopWithdrawals(ApplyWithdrawalsModel applyWithdrawalsModel) {
        applyWithdrawalsModel.setShopId(authHelper.getEnterPriseId());
        applyWithdrawalsModel.setPlatform(false);
        return paymentService2.applicationWithdrawals(applyWithdrawalsModel);
    }

    public ResultContent withdrawalsPlatformApplication(Channel channel) {
        ApplyWithdrawalsModel applyWithdrawalsModel = new ApplyWithdrawalsModel();
        applyWithdrawalsModel.setShopId(channel.name());
        applyWithdrawalsModel.setChannel(channel);
        applyWithdrawalsModel.setPlatform(true);
        return paymentService2.applicationWithdrawals(applyWithdrawalsModel);
    }

    public ResultContent withdrawalsOrderList(WithdrawRequestModel withdrawRequestModel) {
//        String enterPriseId = authHelper.getEnterPriseId();
//        withdrawRequestModel.setShopId(enterPriseId);
        return paymentService2.withdrawalsOrderList(withdrawRequestModel);
    }

    public ResultContent withdrawalsPlatformList(WithdrawRequestModel withdrawRequestModel) {
        withdrawRequestModel.setShopId(withdrawRequestModel.getChannel().name());

        return paymentService2.withdrawalsOrderList(withdrawRequestModel);
    }

    public ResultContent<Page<WithdrawListModel>> withdrawedList(WithdrawedRequestModel withdrawRequestModel) {
        String enterPriseId = authHelper.getEnterPriseId();
        withdrawRequestModel.setShopId(enterPriseId);
        return paymentService2.withdrawalsList(withdrawRequestModel);
    }

    public ResultContent withdrawalsDetail(WithdrawDetailRequestModel withdrawDetailRequestModel) {
        return paymentService2.withdrawalsDetail(withdrawDetailRequestModel);
    }

    public ResultContent withdrawalsDetailList(WithdrawRequestModel withdrawRequestModel) {
        String enterPriseId = authHelper.getEnterPriseId();
        withdrawRequestModel.setShopId(enterPriseId);
        return paymentService2.shopTransferDetail(withdrawRequestModel);
    }

    public ResultContent<AccountCountResponseModel> accountCount(AccountCountRequestModel accountCountRequestModel) {
        String enterPriseId = authHelper.getEnterPriseId();
        accountCountRequestModel.setShopId(enterPriseId);
        return paymentService2.accountCount(accountCountRequestModel);
    }

    public ResultContent<Page<TransferDetailModel>> transferDetail(TransferDetailRequestModel transferDetailRequestModel) {
        String enterPriseId = authHelper.getEnterPriseId();
        transferDetailRequestModel.setShopId(enterPriseId);
        return paymentService2.transferDetail(transferDetailRequestModel);
    }

    public ResultContent applyWithdrawals(AuditWithdrawalsModel auditWithdrawalsModel) {
        AuthDetails currentUser = authHelper.getCurrentUser();
        auditWithdrawalsModel.setAuditName(currentUser.getPhone());
        auditWithdrawalsModel.setUserId(currentUser.getUserId());
        return paymentService2.applyWithdrawals(auditWithdrawalsModel);
    }

    public ResultContent queryWithdrawals(String batchNo) {
        return paymentService2.queryWithdrawals(batchNo);
    }


    public ResultContent subOrdersConfirm(String goodsId, String useShopId) {
        return paymentService2.subOrdersConfirm(goodsId, useShopId);
    }

    public String sync(SyncInformModel syncInformModel) {
        paymentService2.sync(syncInformModel);
        return "SUCCESS";
    }


}
