package com.zswl.cloud.springBtach.server.core.service;


import cn.hutool.core.lang.Snowflake;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.client.content.ResultState;
import com.github.microservice.auth.security.helper.AuthHelper;
import com.zhongshu.payment.client.model.order.v2.*;
import com.zhongshu.payment.client.service.v2.OrderService2;
import com.zhongshu.payment.client.service.v2.PaymentService2;
import com.zhongshu.payment.client.type.JobFlowMap;
import com.zhongshu.payment.client.type.OrderType;
import com.zhongshu.payment.client.type.TransferOwner;
import com.zhongshu.payment.client.type.TransferType;
import com.zswl.cloud.shop.client.service.ShopService;
import com.zswl.cloud.shop.client.vo.life.AccountDetailVo;
import com.zswl.cloud.shop.client.vo.life.SharePlatformVo;
import com.zswl.cloud.springBatch.client.model.ypp.movie.request.CreateOrder2Request;
import com.zswl.cloud.springBatch.client.model.ypp.movie.response.CreateOrder2Response;
import com.zswl.cloud.springBatch.client.model.ypp.movie.response.OrderDetailResponse;
import com.zswl.cloud.springBtach.server.core.api.ypp.YppApi;
import com.zswl.cloud.springBtach.server.core.api.ypp.request.SyncOrderRequest;
import com.zswl.cloud.springBtach.server.core.dao.ApiLogDao;
import com.zswl.cloud.springBtach.server.core.domain.ApiLog;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

@Log4j2
@Service
public class YppService {

    @Autowired
    private YppApi yppApi;

    @Autowired
    private OrderService2 orderService2;

    @Autowired
    private Snowflake snowflake;

    @Autowired
    private AuthHelper authHelper;

    @Autowired
    private ShopService shopService;

    @Autowired
    private ApiLogDao apiLogDao;

    @Autowired
    private PaymentService2 paymentService2;


    public ResultContent<CreatOrderResultModel> create_order(CreateOrder2Request createOrder2Request) {
        com.zswl.cloud.shop.client.ret.ResultContent<AccountDetailVo> shopSetting = shopService.shopSetting("有票票");
        if (!shopSetting.getState().equals(com.zswl.cloud.shop.client.ret.ResultState.Success)) {
            return ResultContent.build(ResultState.Fail, "有票票信息未配置");
        }
        String orderNo = snowflake.nextIdStr();
        AccountDetailVo accountDetailVo = shopSetting.getContent();
        // 分账信息
        String shopId = accountDetailVo.getAccountId();
        String authAccount = accountDetailVo.getAuthAccount();
        SharePlatformVo sharePlatformVo = accountDetailVo.getSharePlatformVo();

        //0 是创建即支付，1是后支付，等待你们的支付通知
        createOrder2Request.setOrderPayMode(1);
        createOrder2Request.setOrderId(orderNo);
        createOrder2Request.setUserMobile(authHelper.getCurrentUser().getPhone());
        CreateOrder2Response createOrder2Response = yppApi.create_order2(createOrder2Request);
        String data = createOrder2Response.getData().getOrderId();

//        CreateOrdereResponse createOrdereResponse = yppApi.create_order(createOrdereRquest);
//        String data = createOrdereResponse.getData();
        OrderDetailResponse orderDetailResponse = yppApi.order_detail(data);
        BigDecimal totalUserPrice = orderDetailResponse.getData().getTotalUserPrice();


        CreateOrder2Model createOrder2Model = new CreateOrder2Model();
        createOrder2Model.setOrderNo(orderNo);
        createOrder2Model.setUserId(authHelper.getCurrentUser().getUserId());
        createOrder2Model.setShopId(shopId);
        JSONObject shopInfo = new JSONObject();
        shopInfo.set("shopName", createOrder2Request.getCinemaName());
        createOrder2Model.setShopInfo(shopInfo);
        createOrder2Model.setTotalAmount(totalUserPrice);
        createOrder2Model.setDiscountAmount(BigDecimal.ZERO);
        createOrder2Model.setPayAmount(totalUserPrice);
        createOrder2Model.setAccesserUserId(authAccount);
        createOrder2Model.setChannel(createOrder2Request.getChannel());


        JSONObject goodsInfo = JSONUtil.parseObj(createOrder2Request);
        goodsInfo.set("goodsName", createOrder2Request.getMovieName());
        goodsInfo.set("goodsPath", createOrder2Request.getPostImageUrl());
        goodsInfo.set("channelOrderId", data);


        CreateOrder2Model.Goods goods = new CreateOrder2Model.Goods();
        goods.setGoodsId(createOrder2Request.getMovieCode());
        goods.setJobFlowMap(JobFlowMap.YPP);
        goods.setGoodsInfo(goodsInfo);
        goods.setPayAmount(totalUserPrice);
        goods.setValidDay(90);
        goods.setTransferType(sharePlatformVo.getShareType().equals(1) ? TransferType.RATIO : TransferType.FIXED);

        List<CreateOrder2Model.Owner> ownerList = new ArrayList<>();

        CreateOrder2Model.Owner platfor = new CreateOrder2Model.Owner();
        platfor.setOwner(TransferOwner.PLATFORM);
        platfor.setValue(sharePlatformVo.getPlatformRate());

        CreateOrder2Model.Owner buy = new CreateOrder2Model.Owner();
        buy.setOwner(TransferOwner.BUY_SHOP);
        buy.setValue(sharePlatformVo.getBuyShopRate());
        buy.setShopId(shopId);

        CreateOrder2Model.Owner use = new CreateOrder2Model.Owner();
        use.setOwner(TransferOwner.USE_SHOP);
        use.setValue(sharePlatformVo.getCheckShopRate());

        ownerList.add(platfor);
        ownerList.add(buy);
        ownerList.add(use);
        goods.setTransferRrule(ownerList);
        goods.setExtend(JSONUtil.parseObj(createOrder2Response));
        createOrder2Model.setGoodsList(List.of(goods));

        return orderService2.creat(createOrder2Model);
    }

    public ResultContent movies(String cityId, String pageIndex, String pageSize) {
        return ResultContent.buildContent(yppApi.movies(cityId, pageIndex, pageSize));
    }

    public ResultContent coming_movies(String cityId) {
        return ResultContent.buildContent(yppApi.coming_movies(cityId));
    }

    public ResultContent movie_detail(String movieId) {
        return ResultContent.buildContent(yppApi.movie_detail(movieId));
    }

    public ResultContent movie_cinemas(String cityId, String movieId, String day, String lat, String lng) {
        return ResultContent.buildContent(yppApi.movie_cinemas(cityId, movieId, day, lat, lng));
    }

    public ResultContent cinemas(String cityId, String districtId, String brandId, String lat, String lng) {
        return ResultContent.buildContent(yppApi.cinemas(cityId, districtId, brandId, lat, lng));
    }

    public ResultContent cinema_filter(String cityId) {
        return ResultContent.buildContent(yppApi.cinema_filter(cityId));
    }

    public ResultContent get_citys() {
        return ResultContent.buildContent(yppApi.get_citys());
    }

    public ResultContent cinema_shows(String movieId, String cinemaId) {
        return ResultContent.buildContent(yppApi.cinema_shows(movieId, cinemaId));
    }

    public ResultContent session(String sessionId, String cinemaId, String movieId, String sid) {
        return ResultContent.buildContent(yppApi.session(sessionId, cinemaId, movieId, sid));

    }

    public ResultContent ad_configs() {
        return ResultContent.buildContent(yppApi.ad_configs());

    }

    public String syncOrderState(SyncOrderRequest syncOrderRequest) {
        ApiLog apiLog = new ApiLog();
        apiLog.setService("sync");
        apiLog.setSystem("ypp");
        apiLog.setRequest(JSONUtil.toJsonStr(syncOrderRequest));
        apiLogDao.save(apiLog);

        int type = syncOrderRequest.getType();
        switch (type) {
            case 0:
                ResultContent<GoodsResultModel> channelGoods = orderService2.findChannelGoods(JobFlowMap.YPP, syncOrderRequest.getData().getId());
                GoodsResultModel goodsResultModel = channelGoods.getContent();
                UpdateGoodsModel updateGoodsModel = new UpdateGoodsModel();
                updateGoodsModel.setId(goodsResultModel.getId());
                JSONObject entries = JSONUtil.parseObj(goodsResultModel.getExtend());
                entries.put("sync", syncOrderRequest.getData());
                updateGoodsModel.setExtend(entries);
                if (syncOrderRequest.getData().getState().equals("4")) {
                    updateGoodsModel.setGoodsState(OrderType.USED);
                } else if (syncOrderRequest.getData().getState().equals("7")) {
                    ApplicantRefundParam2Model applicantRefundParam2Model = new ApplicantRefundParam2Model();
                    applicantRefundParam2Model.setId(goodsResultModel.getId());
                    applicantRefundParam2Model.setRemark("出票失败退款：" + syncOrderRequest.getData().getRefundAmount());
                    applicantRefundParam2Model.setUserId(goodsResultModel.getUserId());
                    paymentService2.refund(applicantRefundParam2Model);

                }
                orderService2.updateGoods(updateGoodsModel);
                break;
        }


        return "成功";

    }
}
