package com.zswl.cloud.springBtach.server.core.service.impl;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.client.content.ResultState;
import com.github.microservice.auth.security.helper.AuthHelper;
import com.zhongshu.payment.client.model.order.v2.CreatOrderResultModel;
import com.zhongshu.payment.client.model.order.v2.CreateOrder2Model;
import com.zhongshu.payment.client.model.order.v2.GoodsResultModel;
import com.zhongshu.payment.client.model.order.v2.UpdateGoodsModel;
import com.zhongshu.payment.client.service.v2.OrderService2;
import com.zhongshu.payment.client.type.JobFlowMap;
import com.zhongshu.payment.client.type.OrderType;
import com.zhongshu.payment.client.type.TransferOwner;
import com.zhongshu.payment.client.type.TransferType;
import com.zswl.cloud.shop.client.service.ShopService;
import com.zswl.cloud.shop.client.vo.life.AccountDetailVo;
import com.zswl.cloud.springBatch.client.model.qiuxiang.OrderDelitResponse;
import com.zswl.cloud.springBatch.client.model.qiuxiang.OrderRequest;
import com.zswl.cloud.springBatch.client.service.QiuXiangService;
import com.zswl.cloud.springBtach.server.core.api.qiuxiang.QiuXiangApi;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.List;


@Service
@Log4j2
public class QiuXiangServiceImpl implements QiuXiangService {

    @Autowired
    private OrderService2 orderService2;

    @Autowired
    private QiuXiangApi qiuXiangApi;

    @Autowired
    private AuthHelper authHelper;

    @Autowired
    private ShopService shopService;


    @Override
    public ResultContent<CreatOrderResultModel> placeOrder(OrderRequest orderRequest) {
        JSONObject entries = qiuXiangApi.placeOrder(orderRequest);


        String orderId = (String) entries.get("orderId");

        JSONObject orderExtend = qiuXiangApi.orderDelit(orderId);
        OrderDelitResponse orderDelitResponse = orderExtend.toBean(OrderDelitResponse.class);
        com.zswl.cloud.shop.client.ret.ResultContent<AccountDetailVo> shopSetting = shopService.shopSetting("有票票");
        if (!shopSetting.getState().equals(com.zswl.cloud.shop.client.ret.ResultState.Success)) {
            return ResultContent.build(ResultState.Fail, "秋香信息未配置");
        }

        BigDecimal totalPrice = BigDecimal.valueOf(orderDelitResponse.getTotalPrice());
        AccountDetailVo content = shopSetting.getContent();
        CreateOrder2Model createOrder2Model = new CreateOrder2Model();
        createOrder2Model.setChannel(orderRequest.getChannel());
        createOrder2Model.setUserId(authHelper.getCurrentUser().getUserId());
        createOrder2Model.setShopId(content.getAccountId());
        createOrder2Model.setShopInfo(JSONUtil.parseObj(content));
        createOrder2Model.setTotalAmount(totalPrice);
        createOrder2Model.setDiscountAmount(BigDecimal.ZERO);
        createOrder2Model.setPayAmount(totalPrice);
        createOrder2Model.setAccesserUserId(content.getAuthAccount());
        CreateOrder2Model.Goods goods = new CreateOrder2Model.Goods();
        goods.setGoodsId(authHelper.getUserToken());
        goods.setJobFlowMap(JobFlowMap.QiuXiang);
        JSONObject goodsInfo = JSONUtil.parseObj(orderRequest);
        goodsInfo.set("channelOrderId", orderId);
        goods.setGoodsInfo(goodsInfo);
        goods.setExtend(JSONUtil.parseObj(orderDelitResponse));
        goods.setPayAmount(BigDecimal.valueOf(orderDelitResponse.getTotalPrice()));
        goods.setTransferType(TransferType.FIXED);
        CreateOrder2Model.Owner owner = new CreateOrder2Model.Owner();
        owner.setOwner(TransferOwner.PLATFORM);
        owner.setValue(totalPrice);
        goods.setTransferRrule(List.of(owner));
        createOrder2Model.setGoodsList(List.of(goods));


        return orderService2.creat(createOrder2Model);

    }

    @Override
    public ResultContent<OrderDelitResponse> orderDelit(String orderId) {
        ResultContent<GoodsResultModel> goodsResultModelResultContent = orderService2.qrGoods(orderId);
        GoodsResultModel content = goodsResultModelResultContent.getContent();
        JSONObject goodsInfo = content.getGoodsInfo();
        String goodsId = goodsInfo.get("channelOrderId").toString();

        JSONObject entries = qiuXiangApi.orderDelit(goodsId);
        OrderDelitResponse orderDelitResponse = entries.toBean(OrderDelitResponse.class);
        UpdateGoodsModel updateGoodsModel = new UpdateGoodsModel();
        updateGoodsModel.setId(orderId);
        updateGoodsModel.setExtend(JSONUtil.parseObj(orderDelitResponse));
        int orderStatus = orderDelitResponse.getOrderStatus();
        if (orderStatus == 2) {
            updateGoodsModel.setGoodsState(OrderType.USED);
        } else if (orderStatus == -1) {
            updateGoodsModel.setGoodsState(OrderType.CLOSE);
        }


        orderService2.updateGoods(updateGoodsModel);


        return ResultContent.build(ResultState.Success, orderDelitResponse);
    }

    @Override
    public ResultContent<OrderDelitResponse> cancelOrder(String orderId, String reason) {

        ResultContent<GoodsResultModel> goodsResultModelResultContent = orderService2.qrGoods(orderId);
        GoodsResultModel content = goodsResultModelResultContent.getContent();
        JSONObject goodsInfo = content.getGoodsInfo();
        String channelOrderId = goodsInfo.get("channelOrderId").toString();
        JSONObject entries = qiuXiangApi.cancelOrder(channelOrderId, reason);

        String string1 = entries.get("msg").toString();
        if (string1.equals("订单取消成功！")) {
            JSONObject entries1 = qiuXiangApi.orderDelit(channelOrderId);
            UpdateGoodsModel updateGoodsModel = new UpdateGoodsModel();
            updateGoodsModel.setGoodsState(OrderType.CLOSE);
            updateGoodsModel.setExtend(JSONUtil.parseObj(entries1));
            updateGoodsModel.setId(orderId);
            orderService2.updateGoods(updateGoodsModel);

            return ResultContent.build(ResultState.Success, entries);
        } else {

            return ResultContent.build(ResultState.Fail, entries);
        }

    }

    @Override
    public ResultContent<OrderDelitResponse> driverLocation(String orderId) {

        ResultContent<GoodsResultModel> goodsResultModelResultContent = orderService2.qrGoods(orderId);
        GoodsResultModel content = goodsResultModelResultContent.getContent();
        JSONObject goodsInfo = content.getGoodsInfo();
        String goodsId = goodsInfo.get("channelOrderId").toString();

        JSONObject entries = qiuXiangApi.driverLocation(goodsId);

        return ResultContent.build(ResultState.Success, entries);
    }

    @Override
    public ResultContent<OrderDelitResponse> driverLocationLog(String orderId) {

        ResultContent<GoodsResultModel> goodsResultModelResultContent = orderService2.qrGoods(orderId);
        GoodsResultModel content = goodsResultModelResultContent.getContent();
        JSONObject goodsInfo = content.getGoodsInfo();
        String goodsId = goodsInfo.get("channelOrderId").toString();

        JSONArray entries = qiuXiangApi.driverLocationLog(goodsId);

        return ResultContent.build(ResultState.Success, entries);
    }
}
